@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # Copyright 2014-2020 CERN
 #
@@ -16,7 +16,7 @@
 #
 # Authors:
 # - Thomas Beermann <thomas.beermann@cern.ch>, 2014-2020
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2014-2018
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2014-2020
 # - Vincent Garonne <vincent.garonne@cern.ch>, 2015
 # - Martin Barisits <martin.barisits@cern.ch>, 2016-2020
 # - Ruturaj Gujar <ruturaj.gujar23@gmail.com>, 2019
@@ -24,8 +24,6 @@
 # - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
 # - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 # - Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
-#
-# PY3K COMPATIBLE
 
 import re
 import sys
@@ -49,10 +47,10 @@ if sys.version_info > (3, 0):
 escapefunc = None
 try:
     import html
-    escapefunc = html.escape
+    escapefunc = html.escape  # noqa: E1101
 except ImportError:
     import cgi
-    escapefunc = cgi.escape
+    escapefunc = cgi.escape  # noqa: E1101
 
 try:
     from onelogin.saml2.auth import OneLogin_Saml2_Auth
@@ -169,7 +167,7 @@ def select_account_name(identitystr, identity_type, vo=None):
     if vo is not None:
         accounts = identity.list_accounts_for_identity(identitystr, identity_type)
     else:
-        internal_accounts = identity_core.list_accounts_for_identity(identitystr, IdentityType.from_sym(identity_type))
+        internal_accounts = identity_core.list_accounts_for_identity(identitystr, IdentityType[identity_type])
         accounts = [account.external for account in internal_accounts]
         vos = [account.vo for account in internal_accounts]
         if vos:
