@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright 2014-2020 CERN
+# Copyright 2014-2021 CERN
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,13 +16,13 @@
 #
 # Authors:
 # - Thomas Beermann <thomas.beermann@cern.ch>, 2014-2020
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2014-2018
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2014-2020
 # - Vincent Garonne <vincent.garonne@cern.ch>, 2015
 # - Martin Barisits <martin.barisits@cern.ch>, 2016-2020
 # - Ruturaj Gujar <ruturaj.gujar23@gmail.com>, 2019
 # - Jaroslav Guenther <jaroslav.guenther@cern.ch>, 2019-2020
 # - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020-2021
 # - Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
 
 import re
@@ -157,7 +157,7 @@ def select_account_name(identitystr, identity_type, vo=None):
     if vo is not None:
         accounts = identity.list_accounts_for_identity(identitystr, identity_type)
     else:
-        internal_accounts = identity_core.list_accounts_for_identity(identitystr, IdentityType.from_sym(identity_type))
+        internal_accounts = identity_core.list_accounts_for_identity(identitystr, IdentityType[identity_type])
         accounts = [account.external for account in internal_accounts]
         vos = [account.vo for account in internal_accounts]
         if vos:
@@ -171,10 +171,10 @@ def select_account_name(identitystr, identity_type, vo=None):
     if len(accounts) == 0:
         return None, vo
     # check if ui_account param is set
-    ui_account = request.args.get('ui_account', None)
+    ui_account = request.args.get('ui_account', default=None)
     # if yes check if the accounts provided for users identity include this account
     if not ui_account:
-        ui_account = request.args.get('account', None)
+        ui_account = request.args.get('account', default=None)
     if ui_account:
         if ui_account not in accounts:
             return None, vo
